# Onshape Clients

This repo is responsible for generating and disseminating Onshape clients in multiple languages. These clients are for 
use by Onshape developer partners. To learn more, visit the [Onshape Developer Portal](https://dev-portal.onshape.com).

## Example Applications

This repo also features example client applications for each of the client target languages.  To view these, go to the 
folder for your language of choice and select the 'example_programs' folder. Within, there will be several brief scripts
along with a README explaining how to setup and run the client.